@@ -29,11 +29,17 @@ class TestMergingCommon(unittest.TestCase):
         self.assert_(merger3.data_visits is not None)
 
         # Check data and weights dtypes
-        merger4 = Merger(tiler=tiler, data_dtype=np.float32, weights_dtype=np.float32)
+        merger4 = Merger(
+            tiler=tiler,
+            data_dtype=np.float32,
+            weights_dtype=np.float32,
+            window="boxcar",
+        )
         self.assertEqual(merger4.data.dtype, np.float32)
         self.assertEqual(merger4.data_dtype, np.float32)
         self.assertEqual(merger4.weights_sum.dtype, np.float32)
         self.assertEqual(merger4.weights_dtype, np.float32)
+        self.assertEqual(merger4.window.dtype, np.float32)
 
     def test_add(self):
         tiler = Tiler(data_shape=self.data.shape, tile_shape=(10,))
